@@ -20,13 +20,13 @@
 
 const qreal Cell::SIZE = 20.0;
 
-Cell::Cell() : m_type(Cell::WALL), m_element(NULL), m_cost(0), m_parent(NULL)
+Cell::Cell() : m_type(Cell::WALL), m_element(nullptr), m_cost(0), m_parent(nullptr)
 {
 }
 
 Cell::~Cell()
 {
-    m_element = NULL;
+    m_element = nullptr;
     delete m_element;
 }
 
