@@ -82,7 +82,7 @@ public:
     /**
      * Deletes the Character instance.
      */
-    ~Character();
+    ~Character() override;
 
     /**
      * Makes the Character go up.
@@ -192,12 +192,18 @@ protected:
      */
     bool onCenter();
 
+    /**
+     * Checks whether the Character is currently on a Cell center.
+     * @return true if the Character is on a Cell center, false otherwise
+     */
+    bool isOnCenter();
+
     /**
      * Moves the character on the center of its current Cell.
      */
     void moveOnCenter();
 
-signals:
+Q_SIGNALS:
 
     /**
      * Emitted when the character is eaten.
@@ -206,4 +212,3 @@ signals:
 };
 
 #endif
-
