@@ -61,9 +61,9 @@ public:
     /**
      * Deletes the KapmanMainWindow instance.
      */
-    ~KapmanMainWindow();
+    ~KapmanMainWindow() override;
 
-private slots:
+private Q_SLOTS:
 
     /**
      * Initializes the KapmanMainWindow for a new game.
